@@ -99,6 +99,14 @@
 2023.1.15 1.2.15.6
     --- 新增开关按钮(SwitchButton)
     --- 新增调色版(ColorPalette)
+2023.1.15 1.2.15.7
+    --- 调色版相关问题
+            1.修复中间区域无法获取颜色的BUG
+            2.修复中间区域点击无法触发信号BUG
+            3.新增一个获取当前选中颜色的按钮
+            4.新增两个信号(colorNamed,clicked)
+            5.新增两种风格(Style_Black,Style_White)
+    --- 重构 气泡窗口
 '''
 
 # ===============================================
