@@ -27,20 +27,23 @@ class Test(QWidget):
 
 
         self.btn = QPushButton("一号玩家",self)
-        self.btn.resize(130,100)
+        self.btn.resize(130,60)
         self.btn.move(200,200)
 
         # 气泡控件
         self.bu = BubbleWidget(self)
-        self.bu.resize(150,100)
-        self.bu.setDirection(BubbleWidget.Top)
-        self.bu.setDurationTime(BubbleWidget.Be_Forever)
-        self.bu.setAnimationEnabled(True)
-        self.bu.setTrack(self.btn)
-        self.bu.setText("你好世界")
-        # self.bu.setText("hello world")
-
-        self.bu.finished.connect(lambda :print("111111111"))
+        self.bu.move(100,100)
+        self.bu.resize(200,80)
+        # self.bu.setDirection(BubbleWidget.Down)
+        # self.bu.setDurationTime(BubbleWidget.Be_Forever)
+        # self.bu.setAnimationEnabled(True)
+        # self.bu.setTrack(self.btn)
+        # self.bu.setText("你好世界")
+        #
+        #
+        # # self.bu.setText("hello world")
+        #
+        # self.bu.finished.connect(lambda :print("111111111"))
         # self.bu.move(80,100) # 如果不想手动设置位置可以用下面控件追踪功能
 
         # # --------
