@@ -2,7 +2,8 @@ from PyQtGuiLib.header import (
     PYQT_VERSIONS,
     QApplication,
     sys,
-    QWidget
+    QWidget,
+    QPushButton
 )
 
 '''
@@ -18,7 +19,11 @@ class Test_ColorPalette(QWidget):
 
         self.cp = ColorPalette(self)
         self.cp.move(10,10)
+        self.cp.clicked.connect(lambda t,c:print(t,c))
+        self.cp.colorNamed.connect(self.test)
 
+    def test(self,rgba):
+        print(self.cp.getRGBA())
 
 
 if __name__ == '__main__':
