@@ -2,7 +2,16 @@ from PyQtGuiLib.header import (
     PYQT_VERSIONS,
     QApplication,
     sys,
-    QWidget
+    QWidget,
+    qt,
+    QPushButton,
+    Qt,
+    QPalette,
+    QColor,
+    QPaintEvent,
+    QPainter,
+    QBrush,
+    QSize,
 )
 
 '''
@@ -15,8 +24,6 @@ class Test(QWidget):
         self.resize(600,600)
 
 
-
-
 if __name__ == '__main__':
     app = QApplication(sys.argv)
     win = Test()
